(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     11794,        322]*)
(*NotebookOutlinePosition[     12436,        344]*)
(*  CellTagsIndexPosition[     12392,        340]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    \(<< DiscreteMath`RSolve`\)], "Input"],

Cell[CellGroupData[{

Cell["Discrete Systems and Eigenvalues", "Section"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is able to solve simple discrete linear systems using RSolve:"
}], "Text"],

Cell[BoxData[{
    \(Clear[x, y]\), "\[IndentingNewLine]", 
    \(req1\  = \ 
      x[n + 1]\  \[Equal] \ \ \(-4\) 
            x[n] + \(\(2\) \( y[n]\)\(\ \)\)\), "\[IndentingNewLine]", 
    \(req2\  = \ 
      y[n + 1]\  \[Equal] \ \ x[n]\  + \ 2  y[n]\), "\[IndentingNewLine]", 
    \(RSolve[{req1, req2}, {x[n], y[n]}, n]\)}], "Input"],

Cell["\<\
However, more complicated nonlinear systems will usually be too difficult for \
RSolve to solve:\
\>", "Text"],

Cell[BoxData[{
    \(req1\  = \ 
      x[n + 1]\  \[Equal] \ \ \(-4\) x[n] + 2  y[n]\  + \ 
          x[n] y[n]\), "\[IndentingNewLine]", 
    \(req2\  = \ 
      y[n + 1]\  \[Equal] \ \ x[n]\  + \ 2  y[n] - 
          4  x[n] y[n]\), "\[IndentingNewLine]", 
    \(RSolve[{req1, req2}, {x[n], y[n]}, n]\)}], "Input"],

Cell["\<\
This is the discrete dynamical system which corresponds to the one we looked \
at in Lecture 10 for continuous dynamical systems. \
\>", "Text"],

Cell["\<\
We are forced to resort to constructing sequences of solutions and analysing \
those. We can make linear approximations near the fixed points, and try to \
determine stability based on the eigenvalues of a matrix.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Fixed Points", "Subsubsection"],

Cell["The fixed points for the system will satisfy", "Text"],

Cell[BoxData[{
    \(req1\  = \ 
      x\  \[Equal] \ \ \(-4\) x + 2  y\  + \ x\ y\), "\[IndentingNewLine]", 
    \(req2\  = \ 
      y\  \[Equal] \ \ x\  + 
          2  y - \(\(4\)  \(x\)\(\ \)\(y\)\(\ \)\)\), "\[IndentingNewLine]", 
    \(Solve[{req1, req2}, {x, y}]\)}], "Input"],

Cell["\<\
Which, not surprisingly, are the same fixed points we found for the \
continuous system.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection"],

Cell[BoxData[{
    \(Clear[x, y]\), "\[IndentingNewLine]", 
    \(\(num = 10;\)\), "\[IndentingNewLine]", 
    \(\(x[0]\  := \ 7/19;\)\), "\[IndentingNewLine]", 
    \(\(y[0]\  := \ 7/9 + 0.001;\)\), "\[IndentingNewLine]", 
    \(x[n_]\  := \ \(x[n]\  = \(-4\) x[n - 1] + 2  y[n - 1]\  + \ 
          x[n - 1] y[n - 1]\)\), "\[IndentingNewLine]", 
    \(y[n_]\  := \ \(y[n]\  = 
        x[n - 1]\  + \ 2  y[n - 1] - 
          4  x[n - 1] y[n - 1]\)\), "\[IndentingNewLine]", 
    \(\(\(data\  = \ 
        Table[{n, x[n], y[n]}, {n, 0, num}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(phase\  = \ 
        Table[{Part[data, n + 1, 2], Part[data, n + 1, 3]}, {n, 0, 
            num}];\)\), "\[IndentingNewLine]", 
    \(\(datax1\  = \ 
        Table[{Part[data, n + 1, 1], Part[data, n + 1, 2]}, {n, 0, 
            num}];\)\), "\[IndentingNewLine]", 
    \(\(datax2\  = \ 
        Table[{Part[data, n + 1, 1], Part[data, n + 1, 3]}, {n, 0, 
            num}];\)\), "\[IndentingNewLine]", 
    \(plotphase\  = \ 
      ListPlot[phase, PlotJoined \[Rule] True, Frame \[Rule] True, 
        Axes \[Rule] False, 
        FrameLabel \[Rule] {"\<x1\>", "\<x2\>"}]\), "\[IndentingNewLine]", 
    \(plotphase\  = \ 
      ListPlot[datax1, PlotJoined \[Rule] True, Frame \[Rule] True, 
        Axes \[Rule] False, 
        FrameLabel \[Rule] {"\<n\>", "\<x1\>"}]\), "\[IndentingNewLine]", 
    \(plotphase\  = \ 
      ListPlot[datax2, PlotJoined \[Rule] True, Frame \[Rule] True, 
        Axes \[Rule] False, 
        FrameLabel \[Rule] {"\<n\>", "\<x2\>"}]\)}], "Input"],

Cell[BoxData[{
    \(matrix\  = \ {{\(-4\), 2}, {1, 2}}\), "\[IndentingNewLine]", 
    \(MatrixForm[%]\), "\[IndentingNewLine]", 
    \(Eigenvalues[matrix]\), "\[IndentingNewLine]", 
    \(N[%]\)}], "Input"],

Cell[BoxData[{
    \(matrix\  = \ {{\(-29\)/9, 405/171}, {\(-361\)/171, 
          10/19}}\), "\[IndentingNewLine]", 
    \(MatrixForm[%]\), "\[IndentingNewLine]", 
    \(Eigenvalues[matrix]\), "\[IndentingNewLine]", 
    \(N[%]\)}], "Input"],

Cell[BoxData[
    \(Sqrt[\((\(-1.35\))\)^2 + \((1.22)\)^2]\)], "Input"],

Cell[BoxData[{
    \(matrix\  = \ {{\(-0.4\), 0.2}, {0.1, 0.2}}\), "\[IndentingNewLine]", 
    \(MatrixForm[%]\), "\[IndentingNewLine]", 
    \(Eigenvalues[matrix]\), "\[IndentingNewLine]", 
    \(N[%]\)}], "Input"],

Cell[BoxData[{
    \(Clear[x, y]\), "\[IndentingNewLine]", 
    \(\(num = 20;\)\), "\[IndentingNewLine]", 
    \(\(x[0]\  := \ 4/9;\)\), "\[IndentingNewLine]", 
    \(\(y[0]\  := \ 2/3;\)\), "\[IndentingNewLine]", 
    \(x[n_]\  := \ \(x[n]\  = \(-0.4\) x[n - 1] + 0.2  y[n - 1]\  + \ 
          1  x[n - 1] y[n - 1]\)\), "\[IndentingNewLine]", 
    \(y[n_]\  := \ \(y[n]\  = 
        0.1  x[n - 1]\  + \ 0.2  y[n - 1] - 
          4  x[n - 1] y[n - 1]\)\), "\[IndentingNewLine]", 
    \(\(data\  = \ 
        Table[{n, x[n], y[n]}, {n, 0, 
            num}];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Solve[{x\  \[Equal] \(-0.4\) x + 0.2  y\ \  + \ 
            1  x\ y\[IndentingNewLine], 
        y \[Equal] 0.1  x\  + \ 0.2  y - 4  x\ y}, {x, 
        y}]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(phase\  = \ 
        Table[{Part[data, n + 1, 2], Part[data, n + 1, 3]}, {n, 0, 
            num}];\)\), "\[IndentingNewLine]", 
    \(\(datax1\  = \ 
        Table[{Part[data, n + 1, 1], Part[data, n + 1, 2]}, {n, 0, 
            num}];\)\), "\[IndentingNewLine]", 
    \(\(datax2\  = \ 
        Table[{Part[data, n + 1, 1], Part[data, n + 1, 3]}, {n, 0, 
            num}];\)\), "\[IndentingNewLine]", 
    \(plotphase\  = \ 
      ListPlot[phase, PlotJoined \[Rule] True, Frame \[Rule] True, 
        Axes \[Rule] False, 
        FrameLabel \[Rule] {"\<x1\>", "\<x2\>"}]\), "\[IndentingNewLine]", 
    \(plotx1\  = \ 
      ListPlot[datax1, PlotJoined \[Rule] True, Frame \[Rule] True, 
        Axes \[Rule] False, 
        FrameLabel \[Rule] {"\<n\>", "\<x1\>"}]\), "\[IndentingNewLine]", 
    \(plotx2\  = \ 
      ListPlot[datax2, PlotJoined \[Rule] True, Frame \[Rule] True, 
        Axes \[Rule] False, 
        FrameLabel \[Rule] {"\<n\>", "\<x2\>"}]\)}], "Input"],

Cell[BoxData[
    \(<< Graphics`PlotField`\)], "Input"],

Cell[BoxData[{
    \(f1\  = \ \(-0.4\) x + 0.2  y\  + \ 1  x\ y\  - 
        x\), "\[IndentingNewLine]", 
    \(f2\  = 0.1  x\  + \ 0.2  y - 4  x\ y\  - \ y\)}], "Input"],

Cell[BoxData[{
    \(field = 
      PlotVectorField[{f1, f2}, {x, \(-1\), 1}, {y, \(-1\), 3}, 
        Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<x1\>", "\<x2\>"}]\), "\[IndentingNewLine]", 
    \(Show[field, plotphase, AspectRatio \[Rule] 1]\)}], "Input"],

Cell[BoxData[{
    \(Clear[x, y]\), "\[IndentingNewLine]", 
    \(\(num = 6;\)\), "\[IndentingNewLine]", 
    \(\(x[0]\  := \ 5/9;\)\), "\[IndentingNewLine]", 
    \(\(y[0]\  := \ 2/3;\)\), "\[IndentingNewLine]", 
    \(x[n_]\  := \ \(x[n]\  = \(-0.4\) x[n - 1] + 0.2  y[n - 1]\  + \ 
          1  x[n - 1] y[n - 1]\)\), "\[IndentingNewLine]", 
    \(y[n_]\  := \ \(y[n]\  = 
        0.1  x[n - 1]\  + \ 0.2  y[n - 1] - 
          4  x[n - 1] y[n - 1]\)\), "\[IndentingNewLine]", 
    \(\(data\  = \ 
        Table[{n, x[n], y[n]}, {n, 0, 
            num}];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Solve[{x\  \[Equal] \(-0.4\) x + 0.2  y\ \  + \ 
            1  x\ y\[IndentingNewLine], 
        y \[Equal] 0.1  x\  + \ 0.2  y - 4  x\ y}, {x, 
        y}]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(phase\  = \ 
        Table[{Part[data, n + 1, 2], Part[data, n + 1, 3]}, {n, 0, 
            num}];\)\), "\[IndentingNewLine]", 
    \(\(datax1\  = \ 
        Table[{Part[data, n + 1, 1], Part[data, n + 1, 2]}, {n, 0, 
            num}];\)\), "\[IndentingNewLine]", 
    \(\(datax2\  = \ 
        Table[{Part[data, n + 1, 1], Part[data, n + 1, 3]}, {n, 0, 
            num}];\)\), "\[IndentingNewLine]", 
    \(plotphase\  = \ 
      ListPlot[phase, PlotJoined \[Rule] True, Frame \[Rule] True, 
        Axes \[Rule] False, 
        FrameLabel \[Rule] {"\<x1\>", "\<x2\>"}]\), "\[IndentingNewLine]", 
    \(plotphase\  = \ 
      ListPlot[datax1, PlotJoined \[Rule] True, Frame \[Rule] True, 
        Axes \[Rule] False, 
        FrameLabel \[Rule] {"\<n\>", "\<x1\>"}]\), "\[IndentingNewLine]", 
    \(plotphase\  = \ 
      ListPlot[datax2, PlotJoined \[Rule] True, Frame \[Rule] True, 
        Axes \[Rule] False, 
        FrameLabel \[Rule] {"\<n\>", "\<x2\>"}]\)}], "Input"],

Cell[BoxData[
    \(<< Graphics`PlotField`\)], "Input"],

Cell[BoxData[{
    \(f1\  = \ \(-0.4\) x + 0.2  y\  + \ 1  x\ y\  - 
        x\), "\[IndentingNewLine]", 
    \(f2\  = 0.1  x\  + \ 0.2  y - 4  x\ y\  - \ y\)}], "Input"],

Cell[BoxData[
    \(field = 
      PlotVectorField[{f1, f2}, {x, \(-1\), 1}, {y, \(-1\), 1}, 
        Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<x1\>", "\<x2\>"}]\)], "Input"],

Cell[BoxData[
    \(\(-722\)/171 + 1\)], "Input"],

Cell[BoxData[
    \(\(-81\)/171 + 1\)], "Input"],

Cell[BoxData[{
    \(Clear[x]\), "\[IndentingNewLine]", 
    \(RSolve[{x[n] \[Equal] \ \[Lambda]\ x[n - 1]\  + \ x[n - 1]}, x[n], 
      n]\)}], "Input"],

Cell[BoxData[{
    \(matrix\  = \ {{\(-0.4\), 0.2}, {\[Alpha], 
          0.2}}\), "\[IndentingNewLine]", 
    \(MatrixForm[%]\), "\[IndentingNewLine]", 
    \(Eigenvalues[matrix]\), "\[IndentingNewLine]", 
    \(N[%]\), "\[IndentingNewLine]", 
    \(TeXForm[
      1\/2\ \((\(-0.2\) - 
            0.89\ \@\(0.45\[InvisibleSpace] + \ \[Alpha]\))\)]\)}], "Input"],

Cell[BoxData[
    \(Plot[{1\/2\ \((\(-0.2\) - 
              0.89\ \@\(0.45\[InvisibleSpace] + \ \[Alpha]\))\), 
        1\/2\ \((\(-0.2\) + 
              0.89\ \@\(0.45\[InvisibleSpace] + \ \[Alpha]\))\), 
        1, \(-1\)}, {\[Alpha], \(-0.45\), 10}, Frame \[Rule] True, 
      FrameLabel \[Rule] {"\<alpha\>", "\<eigenvalues\>"}]\)], "Input"],

Cell[BoxData[
    \(Solve[
      1\/2\ \((\(-0.2\) - 
              0.89\ \@\(0.45\[InvisibleSpace] + \ \[Alpha]\))\) \[Equal] \(-1\
\), \[Alpha]]\)], "Input"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 997}, {0, 721}},
WindowSize->{498, 563},
WindowMargins->{{1, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 56, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[1786, 55, 51, 0, 59, "Section"],
Cell[1840, 57, 146, 4, 33, "Text"],
Cell[1989, 63, 339, 7, 90, "Input"],
Cell[2331, 72, 120, 3, 52, "Text"],
Cell[2454, 77, 316, 7, 70, "Input"],
Cell[2773, 86, 154, 3, 52, "Text"],
Cell[2930, 91, 237, 4, 71, "Text"],

Cell[CellGroupData[{
Cell[3192, 99, 37, 0, 43, "Subsubsection"],
Cell[3232, 101, 60, 0, 33, "Text"],
Cell[3295, 103, 283, 6, 70, "Input"],
Cell[3581, 111, 112, 3, 33, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3730, 119, 33, 0, 43, "Subsubsection"],
Cell[3766, 121, 1590, 33, 410, "Input"],
Cell[5359, 156, 207, 4, 90, "Input"],
Cell[5569, 162, 242, 5, 90, "Input"],
Cell[5814, 169, 71, 1, 30, "Input"],
Cell[5888, 172, 215, 4, 90, "Input"],
Cell[6106, 178, 1799, 37, 490, "Input"],
Cell[7908, 217, 55, 1, 30, "Input"],
Cell[7966, 220, 170, 3, 50, "Input"],
Cell[8139, 225, 265, 5, 70, "Input"],
Cell[8407, 232, 1804, 37, 490, "Input"],
Cell[10214, 271, 55, 1, 30, "Input"],
Cell[10272, 274, 170, 3, 50, "Input"],
Cell[10445, 279, 184, 4, 50, "Input"],
Cell[10632, 285, 49, 1, 30, "Input"],
Cell[10684, 288, 48, 1, 30, "Input"],
Cell[10735, 291, 153, 3, 50, "Input"],
Cell[10891, 296, 363, 8, 123, "Input"],
Cell[11257, 306, 347, 6, 85, "Input"],
Cell[11607, 314, 159, 4, 42, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

