(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     16665,        425]*)
(*NotebookOutlinePosition[     17307,        447]*)
(*  CellTagsIndexPosition[     17263,        443]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Henon-Heiles Model", "Subsubsection"],

Cell["\<\
These equations model a star moving in the field of its galaxy. The model \
possesses chaotic orbits. The dynamical system is continuous, and is governed \
by Hamilton's equations from physics for the motion of a particle. \
\>", "Text"],

Cell[BoxData[{
    \(Clear[x, y, px, py]\), "\[IndentingNewLine]", 
    \(Hamiltonian[x_, y_, px_, 
        py_]\  = \ \((px^2 + py^2 + x^2 + y^2)\)/
          2 + \((x^2  y - y^3/3)\)\)}], "Input"],

Cell[BoxData[{
    \(Clear[x, y, px, py]\), "\[IndentingNewLine]", 
    \(eq1\  = \ \(y'\)[t]\  \[Equal] 
        D[Hamiltonian[x[t], y[t], px[t], py[t]], 
          py[t]]\), "\[IndentingNewLine]", 
    \(eq2\  = \ \(x'\)[t]\  \[Equal] 
        D[Hamiltonian[x[t], y[t], px[t], py[t]], 
          px[t]]\), "\[IndentingNewLine]", 
    \(eq3\  = \ \(px'\)[t]\  \[Equal] \(-\ 
          D[Hamiltonian[x[t], y[t], px[t], py[t]], 
            x[t]]\)\), "\[IndentingNewLine]", 
    \(eq4\  = \ \(py'\)[t]\  \[Equal] \(-\ 
          D[Hamiltonian[x[t], y[t], px[t], py[t]], y[t]]\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is unable to solve this system analytically."
}], "Text"],

Cell[BoxData[
    \(DSolve[{eq1, eq2, eq3, eq4}, {px[t], py[t], y[t], x[t]}, t]\)], "Input"],

Cell["\<\
However, we can approximate it using Euler's method, and then proceed to \
analyze the system.\
\>", "Text"],

Cell[BoxData[{
    \(f1[x_, y_, px_, py_]\  = \ 
      D[Hamiltonian[x, y, px, py], px]\), "\[IndentingNewLine]", 
    \(f2[x_, y_, px_, py_]\  = \ 
      D[Hamiltonian[x, y, px, py], py]\), "\[IndentingNewLine]", 
    \(f3[x_, y_, px_, py_]\  = \(-\ 
        D[Hamiltonian[x, y, px, py], x]\)\), "\[IndentingNewLine]", 
    \(f4[x_, y_, px_, py_]\  = \(-\ 
        D[Hamiltonian[x, y, px, py], y]\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(Clear[x, y, px, py]\), "\n", 
    \(x[0] := \ 0.1\), "\n", 
    \(y[0] := \ 0.05\), "\n", 
    \(px[0] := \ 0.0\), "\n", 
    \(\(\(py[0] := \ 0.11\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(num = 50000;\)\), "\[IndentingNewLine]", 
    \(\(to\  = \ 0;\)\), "\[IndentingNewLine]", 
    \(\(tf\  = \ 100;\)\), "\[IndentingNewLine]", 
    \(h\  = \ 
      N[\((tf - to)\)/num]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(x[n_] := \ \(x[n]\  = \ 
        h\ f1[x[n - 1], y[n - 1], px[n - 1], py[n - 1]] + 
          x[n - 1]\)\), "\n", 
    \(y[n_] := \ \(y[n]\  = \ 
        h\ f2[x[n - 1], y[n - 1], px[n - 1], py[n - 1]] + 
          y[n - 1]\)\), "\[IndentingNewLine]", 
    \(px[n_] := \ \(px[n]\  = \ 
        h\ f3[x[n - 1], y[n - 1], px[n - 1], py[n - 1]] + 
          px[n - 1]\)\), "\[IndentingNewLine]", 
    \(py[n_] := \ \(py[n]\  = \ 
        h\ f4[x[n - 1], y[n - 1], px[n - 1], py[n - 1]] + 
          py[n - 1]\)\n\), "\n", 
    \(\(data\  = \ 
        Table[{h*n, x[n], y[n], px[n], py[n]}, {n, 0, 
            num}];\)\[IndentingNewLine]\), "\n", 
    \(\(xyphase\  = \ 
        Table[{Part[data, n + 1, 2], Part[data, n + 1, 3]}, {n, 0, 
            num}];\)\), "\[IndentingNewLine]", 
    \(phaseplot = 
      ListPlot[xyphase, 
        PlotRange \[Rule] {{\(-0.15\), 0.15}, {\(-0.15\), 0.15}}, 
        PlotJoined \[Rule] True, Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {RGBColor[1, 0, 
              0]}]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(xtime\  = \ 
        Table[{Part[data, n + 1, 1], Part[data, n + 1, 2]}, {n, 0, 
            num}];\)\), "\[IndentingNewLine]", 
    \(xplot = 
      ListPlot[xtime, PlotRange \[Rule] All, PlotJoined \[Rule] True, 
        Frame \[Rule] True, FrameLabel \[Rule] {"\<Time\>", "\<x\>"}, 
        PlotStyle \[Rule] {RGBColor[1, 0, 0]}]\)}], "Input"],

Cell["Here is another trajectory in the Henon Heiles model:", "Text"],

Cell[BoxData[{
    \(Clear[x, y, px, py]\), "\n", 
    \(x[0] := \ 0.2\), "\n", 
    \(y[0] := \ 0.1\), "\n", 
    \(px[0] := \ 0.04\), "\n", 
    \(\(\(py[0] := \ \(-0.05\)\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(num = 50000;\)\), "\[IndentingNewLine]", 
    \(\(to\  = \ 0;\)\), "\[IndentingNewLine]", 
    \(\(tf\  = \ 140;\)\), "\[IndentingNewLine]", 
    \(\(\(h\  = \ N[\((tf - to)\)/num]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(x[n_] := \ \(x[n]\  = \ 
        h\ f1[x[n - 1], y[n - 1], px[n - 1], py[n - 1]] + 
          x[n - 1]\)\), "\n", 
    \(y[n_] := \ \(y[n]\  = \ 
        h\ f2[x[n - 1], y[n - 1], px[n - 1], py[n - 1]] + 
          y[n - 1]\)\), "\[IndentingNewLine]", 
    \(px[n_] := \ \(px[n]\  = \ 
        h\ f3[x[n - 1], y[n - 1], px[n - 1], py[n - 1]] + 
          px[n - 1]\)\), "\[IndentingNewLine]", 
    \(\(\(py[n_] := \ \(py[n]\  = \ 
        h\ f4[x[n - 1], y[n - 1], px[n - 1], py[n - 1]] + py[n - 1]\)\)\(\n\)
    \)\), "\n", 
    \(\(\(data\  = \ 
        Table[{h*n, x[n], y[n], px[n], py[n]}, {n, 0, 
            num}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(xyphase\  = \ 
        Table[{Part[data, n + 1, 2], Part[data, n + 1, 3]}, {n, 0, 
            num}];\)\), "\[IndentingNewLine]", 
    \(\(\(phaseplot1 = 
      ListPlot[xyphase, PlotRange \[Rule] {{\(-0.4\), 0.4}, {\(-0.4\), 0.4}}, 
        PlotJoined \[Rule] True, Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {RGBColor[1, 0, 0]}]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(xtime\  = \ 
        Table[{Part[data, n + 1, 1], Part[data, n + 1, 2]}, {n, 0, 
            num}];\)\), "\[IndentingNewLine]", 
    \(xplot1 = 
      ListPlot[xtime, PlotRange \[Rule] All, PlotJoined \[Rule] True, 
        Frame \[Rule] True, FrameLabel \[Rule] {"\<Time\>", "\<x\>"}, 
        PlotStyle \[Rule] {RGBColor[1, 0, 0]}]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Rossler Attractor", "Subsubsection"],

Cell["This attractor I will solve numerically using NDSolve.", "Text"],

Cell[BoxData[{
    \(\(\(Clear[x, y, z, f1, f2, f3, t, c, sol]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(tf\  = \ 210;\)\), "\[IndentingNewLine]", 
    \(\(\(sol\  = 
      NDSolve[{\[IndentingNewLine]\(x'\)[t] \[Equal] \(-\((y[t] + z[t])\)\), 
          x[0] \[Equal] \(-0.04\), \[IndentingNewLine]\(y'\)[t] \[Equal] 
            x[t] + 0.2\ y[t], 
          y[0] \[Equal] \(-0.3\), \(z'\)[t] \[Equal] 
            0.2 + x\ [t] z[t] - 5.7\ z[t], z[0] \[Equal] 0.2}, {x, y, z}, {t, 
          0, tf}, Method \[Rule] RungeKutta, 
        MaxSteps \[Rule] 2000]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(plot1 = 
      ParametricPlot3D[Evaluate[{x[t], y[t], z[t]} /. sol], {t, 0, tf}, 
        PlotPoints \[Rule] 6000, 
        PlotRange \[Rule] All]\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(Clear[x, y, z, f1, f2, f3, t, c, 
      sol]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(tf\  = \ 210;\)\), "\[IndentingNewLine]", 
    \(sol\  = 
      NDSolve[{\[IndentingNewLine]\(x'\)[t] \[Equal] \(-\((y[t] + z[t])\)\), 
          x[0] \[Equal] \(-0.04\), \[IndentingNewLine]\(y'\)[t] \[Equal] 
            x[t] + 0.2\ y[t], 
          y[0] \[Equal] \(-0.3\), \(z'\)[t] \[Equal] 
            0.2 + x\ [t] z[t] - 5.7\ z[t], z[0] \[Equal] 0.2}, {x, y, z}, {t, 
          0, tf}, Method \[Rule] RungeKutta, 
        MaxSteps \[Rule] 2000]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(plot1 = 
      ParametricPlot3D[Evaluate[{x[t], y[t], z[t]} /. sol], {t, 0, tf}, 
        PlotPoints \[Rule] 6000, 
        PlotRange \[Rule] All]\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["An nimation of the Rossler attractor:", "Text"],

Cell[BoxData[
    \(\(\(Do[{Clear[x, y, z, f1, f2, f3, t, c, 
          sol], \[IndentingNewLine]c\  = \ 5.7, \[IndentingNewLine]sol\  = 
          NDSolve[{\[IndentingNewLine]\(x'\)[
                  t] \[Equal] \(-\((y[t] + z[t])\)\), 
              x[0] \[Equal] \(-0.04\), \[IndentingNewLine]\(y'\)[t] \[Equal] 
                x[t] + 0.2\ y[t], 
              y[0] \[Equal] \(-0.3\), \(z'\)[t] \[Equal] 
                0.2 + x\ [t] z[t] - c\ z[t], z[0] \[Equal] 0.2}, {x, y, 
              z}, {t, 0, tf}, Method \[Rule] RungeKutta, 
            MaxSteps \[Rule] 2000], \[IndentingNewLine]plot1 = 
          ParametricPlot3D[Evaluate[{x[t], y[t], z[t]} /. sol], {t, 0, tf}, 
            PlotPoints \[Rule] 4000, 
            PlotRange \[Rule] {{\(-10\), 15}, {\(-12\), 10}, {0, 25}}]}, {tf, 
        10, 110, 1}]\)\(\[IndentingNewLine]\)
    \)\)], "Input"],

Cell[BoxData[{
    \(\(\(Clear[x, y, z, f1, f2, f3, t, c, sol]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(tf\  = \ 200;\)\), "\[IndentingNewLine]", 
    \(\(\(sol\  = 
        NDSolve[{\[IndentingNewLine]\(x'\)[
                t] \[Equal] \(-\((y[t] + z[t])\)\), 
            x[0] \[Equal] \(-0.04\), \[IndentingNewLine]\(y'\)[t] \[Equal] 
              x[t] + 0.2\ y[t], 
            y[0] \[Equal] \(-0.3\), \(z'\)[t] \[Equal] 
              0.2 + x\ [t] z[t] - 5.7\ z[t], z[0] \[Equal] 0.2}, {x, y, 
            z}, {t, 0, tf}, Method \[Rule] RungeKutta, 
          MaxSteps \[Rule] 2000];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(xone[t_]\  = \ {x[t]} /. sol;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(plot1 = 
      Plot[Evaluate[xone[t]], {t, 0, tf}, PlotPoints \[Rule] 6000, 
        PlotRange \[Rule] All, 
        PlotStyle \[Rule] {RGBColor[0, 0, 1]}]\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["How we know we have chaos in the Rossler attractor:", "Text"],

Cell[BoxData[{
    \(\(\(Clear[x, y, z, f1, f2, f3, t, c, sol]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(tf\  = \ 200;\)\), "\[IndentingNewLine]", 
    \(\(\(sol\  = 
        NDSolve[{\[IndentingNewLine]\(x'\)[
                t] \[Equal] \(-\((y[t] + z[t])\)\), 
            x[0] \[Equal] \(-0.045\), \[IndentingNewLine]\(y'\)[t] \[Equal] 
              x[t] + 0.2\ y[t], 
            y[0] \[Equal] \(-0.3\), \(z'\)[t] \[Equal] 
              0.2 + x\ [t] z[t] - 5.7\ z[t], z[0] \[Equal] 0.2}, {x, y, 
            z}, {t, 0, tf}, Method \[Rule] RungeKutta, 
          MaxSteps \[Rule] 2000];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(plot2 = 
      Plot[Evaluate[{x[t]} /. sol], {t, 0, tf}, PlotPoints \[Rule] 6000, 
        PlotRange \[Rule] All, 
        PlotStyle \[Rule] {RGBColor[0, 0, 1]}]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(plot3 = 
      Plot[Evaluate[xone[t]\  - {x[t]} /. sol], {t, 0, tf}, 
        PlotPoints \[Rule] 6000, PlotRange \[Rule] All, 
        PlotStyle \[Rule] {RGBColor[1, 0, 0]}]\), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Henon Map", "Subsubsection"],

Cell[BoxData[{
    \(Clear[x, y]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(x[0]\  := \ \(-1\)\), "\[IndentingNewLine]", 
    \(y[0]\  := \ 0\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(x[n_]\  := \ \(x[n]\  = \ 
        y[n - 1]\  + 1 - 1.4  x[n - 1]^2\)\), "\[IndentingNewLine]", 
    \(y[n_]\  := \ \(y[n] = 
        0.3  x[n - 1]\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(points\  = \ 
        Table[{x[n], y[n]}, {n, 0, 
            12000}];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(plot1\  = \ 
      ListPlot[points, Frame \[Rule] True, Axes \[Rule] False, 
        FrameLabel \[Rule] {"\<x\>", "\<y\>"}]\)}], "Input"],

Cell[BoxData[{
    \(Clear[x, y]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(x[0]\  := \ 1\), "\[IndentingNewLine]", 
    \(y[0]\  := \ \(-0.3\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(x[n_]\  := \ \(x[n]\  = \ 
        y[n - 1]\  + 1 - 1.4  x[n - 1]^2\)\), "\[IndentingNewLine]", 
    \(y[n_]\  := \ \(y[n] = 
        0.3  x[n - 1]\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(points\  = \ 
        Table[{x[n], y[n]}, {n, 0, 
            12000}];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(plot2\  = \ 
      ListPlot[points, Frame \[Rule] True, Axes \[Rule] False, 
        FrameLabel \[Rule] {"\<x\>", "\<y\>"}]\)}], "Input"],

Cell[BoxData[
    \(Show[plot1, plot2]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Fractals", "Subsubsection"],

Cell["\<\
Here is the Julia set, on two different scales, to show self similarity \
(fractal):\
\>", "Text"],

Cell[BoxData[{
    \(Clear[z]\), "\[IndentingNewLine]", 
    \(c\  = \ I\), "\[IndentingNewLine]", 
    \(z[0]\  := \ 0.5\), "\[IndentingNewLine]", 
    \(z[n_] := \(z[n] = 
        If[Random[Integer] \[Equal] 1, 
          Sqrt[z[n - 1] - c], \(-Sqrt[
              z[n - 1] - 
                c]\)]\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(JuliaSet\  = \ 
        Table[{Re[z[n]], Im[z[n]]}, {n, 0, 
            500000}];\)\), "\[IndentingNewLine]", 
    \(ListPlot[Take[JuliaSet, 10000], AspectRatio \[Rule] 1, \ 
      Frame \[Rule] True, \ Axes \[Rule] False, 
      PlotRange \[Rule] {{\(-1.5\), 1.5}, {\(-1.5\), 
            1.5}}]\), "\[IndentingNewLine]", 
    \(ListPlot[JuliaSet, AspectRatio \[Rule] 1, \ Frame \[Rule] True, \ 
      Axes \[Rule] False, 
      PlotRange \[Rule] {{\(-0.15\), 0.15}, {\(-0.15\), 0.15}}]\)}], "Input"],

Cell[BoxData[{
    \(Clear[z]\), "\[IndentingNewLine]", 
    \(c\  = I\), "\[IndentingNewLine]", 
    \(z[0]\  := \ \(-1.0\) - 1.0  I\), "\[IndentingNewLine]", 
    \(z[n_] := \(z[n] = 
        If[Random[Integer] \[Equal] 1, 
          Sqrt[z[n - 1] - c], \(-Sqrt[
              z[n - 1] - 
                c]\)]\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(JuliaSet\  = \ 
        Table[{Re[z[n]], Im[z[n]]}, {n, 0, 
            500000}];\)\), "\[IndentingNewLine]", 
    \(ListPlot[Take[JuliaSet, 10000], AspectRatio \[Rule] 1, \ 
      Frame \[Rule] True, \ Axes \[Rule] False, 
      PlotRange \[Rule] {{\(-1.5\), 1.5}, {\(-1.5\), 
            1.5}}]\), "\[IndentingNewLine]", 
    \(ListPlot[JuliaSet, AspectRatio \[Rule] 1, \ Frame \[Rule] True, \ 
      Axes \[Rule] False, 
      PlotRange \[Rule] {{\(-0.15\), 0.15}, {\(-0.15\), 0.15}}]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["References", "Subsubsection"],

Cell["Fractals:", "Text"],

Cell[TextData[ButtonBox["http://mathforum.org/advanced/robertd/index.html#\
frac",
  ButtonData:>{
    URL[ "http://mathforum.org/advanced/robertd/index.html#frac"], None},
  ButtonStyle->"Hyperlink"]], "Text"],

Cell["Attractors, with animation:", "Text"],

Cell[TextData[ButtonBox["http://www.cs.gsu.edu/~cscrwh/dynam/dynam.html",
  ButtonData:>{
    URL[ "http://www.cs.gsu.edu/~cscrwh/dynam/dynam.html"], None},
  ButtonStyle->"Hyperlink"]], "Text"],

Cell["Fractal music:", "Text"],

Cell[TextData[ButtonBox["http://www.thinks.com/sounds/fractal.htm",
  ButtonData:>{
    URL[ "http://www.thinks.com/sounds/fractal.htm"], None},
  ButtonStyle->"Hyperlink"]], "Text"]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 997}, {0, 721}},
WindowSize->{499, 563},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 43, 0, 43, "Subsubsection"],
Cell[1773, 54, 247, 4, 71, "Text"],
Cell[2023, 60, 198, 4, 70, "Input"],
Cell[2224, 66, 591, 12, 190, "Input"],
Cell[2818, 80, 129, 4, 33, "Text"],
Cell[2950, 86, 92, 1, 50, "Input"],
Cell[3045, 89, 118, 3, 52, "Text"],
Cell[3166, 94, 447, 9, 110, "Input"],
Cell[3616, 105, 1914, 43, 730, "Input"],
Cell[5533, 150, 69, 0, 33, "Text"],
Cell[5605, 152, 1939, 43, 730, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7581, 200, 46, 0, 43, "Subsubsection"],
Cell[7630, 202, 70, 0, 33, "Text"],
Cell[7703, 204, 844, 17, 290, "Input"],
Cell[8550, 223, 817, 16, 250, "Input"],
Cell[9370, 241, 53, 0, 33, "Text"],
Cell[9426, 243, 864, 15, 290, "Input"],
Cell[10293, 260, 984, 20, 310, "Input"],
Cell[11280, 282, 67, 0, 33, "Text"],
Cell[11350, 284, 1135, 23, 370, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12522, 312, 38, 0, 43, "Subsubsection"],
Cell[12563, 314, 669, 13, 250, "Input"],
Cell[13235, 329, 671, 13, 250, "Input"],
Cell[13909, 344, 51, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13997, 350, 33, 0, 43, "Subsubsection"],
Cell[14033, 352, 108, 3, 33, "Text"],
Cell[14144, 357, 858, 18, 270, "Input"],
Cell[15005, 377, 870, 18, 270, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15912, 400, 35, 0, 43, "Subsubsection"],
Cell[15950, 402, 25, 0, 33, "Text"],
Cell[15978, 404, 210, 4, 33, "Text"],
Cell[16191, 410, 43, 0, 33, "Text"],
Cell[16237, 412, 194, 3, 33, "Text"],
Cell[16434, 417, 30, 0, 33, "Text"],
Cell[16467, 419, 182, 3, 33, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

